# coding: utf-8

# flake8: noqa

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from neuronpedia_autointerp_client.api.default_api import DefaultApi

# import ApiClient
from neuronpedia_autointerp_client.api_response import ApiResponse
from neuronpedia_autointerp_client.api_client import ApiClient
from neuronpedia_autointerp_client.configuration import Configuration
from neuronpedia_autointerp_client.exceptions import OpenApiException
from neuronpedia_autointerp_client.exceptions import ApiTypeError
from neuronpedia_autointerp_client.exceptions import ApiValueError
from neuronpedia_autointerp_client.exceptions import ApiKeyError
from neuronpedia_autointerp_client.exceptions import ApiAttributeError
from neuronpedia_autointerp_client.exceptions import ApiException

# import models into sdk package
from neuronpedia_autointerp_client.models.explain_default_post200_response import ExplainDefaultPost200Response
from neuronpedia_autointerp_client.models.explain_default_post_request import ExplainDefaultPostRequest
from neuronpedia_autointerp_client.models.np_activation import NPActivation
from neuronpedia_autointerp_client.models.np_score_fuzz_detection_type import NPScoreFuzzDetectionType
from neuronpedia_autointerp_client.models.score_embedding_post200_response import ScoreEmbeddingPost200Response
from neuronpedia_autointerp_client.models.score_embedding_post200_response_breakdown_inner import ScoreEmbeddingPost200ResponseBreakdownInner
from neuronpedia_autointerp_client.models.score_embedding_post_request import ScoreEmbeddingPostRequest
from neuronpedia_autointerp_client.models.score_fuzz_detection_post200_response import ScoreFuzzDetectionPost200Response
from neuronpedia_autointerp_client.models.score_fuzz_detection_post200_response_breakdown_inner import ScoreFuzzDetectionPost200ResponseBreakdownInner
from neuronpedia_autointerp_client.models.score_fuzz_detection_post_request import ScoreFuzzDetectionPostRequest



# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.models.score_embedding_post200_response_breakdown_inner import ScoreEmbeddingPost200ResponseBreakdownInner

class TestScoreEmbeddingPost200ResponseBreakdownInner(unittest.TestCase):
    """ScoreEmbeddingPost200ResponseBreakdownInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScoreEmbeddingPost200ResponseBreakdownInner:
        """Test ScoreEmbeddingPost200ResponseBreakdownInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScoreEmbeddingPost200ResponseBreakdownInner`
        """
        model = ScoreEmbeddingPost200ResponseBreakdownInner()
        if include_optional:
            return ScoreEmbeddingPost200ResponseBreakdownInner(
                text = '',
                distance = 56,
                similarity = 1.337
            )
        else:
            return ScoreEmbeddingPost200ResponseBreakdownInner(
                text = '',
                distance = 56,
                similarity = 1.337,
        )
        """

    def testScoreEmbeddingPost200ResponseBreakdownInner(self):
        """Test ScoreEmbeddingPost200ResponseBreakdownInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.models.score_fuzz_detection_post200_response_breakdown_inner import ScoreFuzzDetectionPost200ResponseBreakdownInner

class TestScoreFuzzDetectionPost200ResponseBreakdownInner(unittest.TestCase):
    """ScoreFuzzDetectionPost200ResponseBreakdownInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScoreFuzzDetectionPost200ResponseBreakdownInner:
        """Test ScoreFuzzDetectionPost200ResponseBreakdownInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScoreFuzzDetectionPost200ResponseBreakdownInner`
        """
        model = ScoreFuzzDetectionPost200ResponseBreakdownInner()
        if include_optional:
            return ScoreFuzzDetectionPost200ResponseBreakdownInner(
                str_tokens = [
                    ''
                    ],
                activations = [
                    1.337
                    ],
                distance = 56,
                ground_truth = True,
                prediction = True,
                highlighted = True,
                probability = 1.337,
                correct = True
            )
        else:
            return ScoreFuzzDetectionPost200ResponseBreakdownInner(
        )
        """

    def testScoreFuzzDetectionPost200ResponseBreakdownInner(self):
        """Test ScoreFuzzDetectionPost200ResponseBreakdownInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_explain_default_post(self) -> None:
        """Test case for explain_default_post

        Generate an explanation for neuron/feature behavior using the default explainer
        """
        pass

    def test_score_embedding_post(self) -> None:
        """Test case for score_embedding_post

        Score an explanation using embedding similarity, using the dunzhang/stella_en_400M_v5 model.
        """
        pass

    def test_score_fuzz_detection_post(self) -> None:
        """Test case for score_fuzz_detection_post

        Score an explanation using fuzzing or detection methods
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.models.np_score_fuzz_detection_type import NPScoreFuzzDetectionType

class TestNPScoreFuzzDetectionType(unittest.TestCase):
    """NPScoreFuzzDetectionType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNPScoreFuzzDetectionType(self):
        """Test NPScoreFuzzDetectionType"""
        # inst = NPScoreFuzzDetectionType()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neuronpedia_autointerp_client.models.score_fuzz_detection_post200_response import ScoreFuzzDetectionPost200Response

class TestScoreFuzzDetectionPost200Response(unittest.TestCase):
    """ScoreFuzzDetectionPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScoreFuzzDetectionPost200Response:
        """Test ScoreFuzzDetectionPost200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScoreFuzzDetectionPost200Response`
        """
        model = ScoreFuzzDetectionPost200Response()
        if include_optional:
            return ScoreFuzzDetectionPost200Response(
                score = 1.337,
                breakdown = [
                    neuronpedia_autointerp_client.models._score_fuzz_detection_post_200_response_breakdown_inner._score_fuzz_detection_post_200_response_breakdown_inner(
                        str_tokens = [
                            ''
                            ], 
                        activations = [
                            1.337
                            ], 
                        distance = 56, 
                        ground_truth = True, 
                        prediction = True, 
                        highlighted = True, 
                        probability = 1.337, 
                        correct = True, )
                    ]
            )
        else:
            return ScoreFuzzDetectionPost200Response(
                score = 1.337,
                breakdown = [
                    neuronpedia_autointerp_client.models._score_fuzz_detection_post_200_response_breakdown_inner._score_fuzz_detection_post_200_response_breakdown_inner(
                        str_tokens = [
                            ''
                            ], 
                        activations = [
                            1.337
                            ], 
                        distance = 56, 
                        ground_truth = True, 
                        prediction = True, 
                        highlighted = True, 
                        probability = 1.337, 
                        correct = True, )
                    ],
        )
        """

    def testScoreFuzzDetectionPost200Response(self):
        """Test ScoreFuzzDetectionPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Neuronpedia - AutoInterp Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Contact: johnny@neuronpedia.org
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from neuronpedia_autointerp_client.models.explain_default_post200_response import ExplainDefaultPost200Response
from neuronpedia_autointerp_client.models.explain_default_post_request import ExplainDefaultPostRequest
from neuronpedia_autointerp_client.models.np_activation import NPActivation
from neuronpedia_autointerp_client.models.np_score_fuzz_detection_type import NPScoreFuzzDetectionType
from neuronpedia_autointerp_client.models.score_embedding_post200_response import ScoreEmbeddingPost200Response
from neuronpedia_autointerp_client.models.score_embedding_post200_response_breakdown_inner import ScoreEmbeddingPost200ResponseBreakdownInner
from neuronpedia_autointerp_client.models.score_embedding_post_request import ScoreEmbeddingPostRequest
from neuronpedia_autointerp_client.models.score_fuzz_detection_post200_response import ScoreFuzzDetectionPost200Response
from neuronpedia_autointerp_client.models.score_fuzz_detection_post200_response_breakdown_inner import ScoreFuzzDetectionPost200ResponseBreakdownInner
from neuronpedia_autointerp_client.models.score_fuzz_detection_post_request import ScoreFuzzDetectionPostRequest
